<?php
/**
 * add menu of vicuna options
 */
function add_vicuna_layout_menu() {
	add_theme_page(__('Layout', 'vicuna'), __('Layout', 'vicuna'), 0, basename(__FILE__), 'vicuna_layout_menu');
}
add_action( 'admin_menu', 'add_vicuna_layout_menu' );

/**
 * Get a parameter for layout in the page.
 */
function vicuna_layout($page) {
	$options = get_option('vicuna_layout');
	$key = $page . '_layout';
	if (!isset($options[$key])) {
		$options['index_layout'] = 'double';
		$options['category_layout'] = 'double';
		$options['archive_layout'] = 'double';
		$options['tag_layout'] = 'double';
		$options['page_layout'] = 'single';
		$options['single_layout'] = 'single';
		$options['search_layout'] = 'double';
		$options['404_layout'] = 'single';
		update_option('vicuna_layout', $options);
	}
	echo $options[$key];
}

/**
 * Update parameters of layout
 */
function update_vicuna_layout() {
	$options = get_option('vicuna_layout');
	if (isset($_POST['vicuna_index_layout'])) {
		$options['index_layout'] = $_POST['vicuna_index_layout'];
	}
	if (isset($_POST['vicuna_category_layout'])) {
		$options['category_layout'] = $_POST['vicuna_category_layout'];
	}
	if (isset($_POST['vicuna_archive_layout'])) {
		$options['archive_layout'] = $_POST['vicuna_archive_layout'];
	}
	if (isset($_POST['vicuna_tag_layout'])) {
		$options['tag_layout'] = $_POST['vicuna_tag_layout'];
	}
	if (isset($_POST['vicuna_page_layout'])) {
		$options['page_layout'] = $_POST['vicuna_page_layout'];
	}
	if (isset($_POST['vicuna_single_layout'])) {
		$options['single_layout'] = $_POST['vicuna_single_layout'];
	}
	if (isset($_POST['vicuna_search_layout'])) {
		$options['search_layout'] = $_POST['vicuna_search_layout'];
	}
	if (isset($_POST['vicuna_404_layout'])) {
		$options['404_layout'] = $_POST['vicuna_404_layout'];
	}
	if (isset($_POST['vicuna_3column_type'])) {
		$options['3column_type'] = $_POST['vicuna_3column_type'];
	}
	update_option('vicuna_layout', $options);
}
add_action( 'init', 'update_vicuna_layout');

/**
 * Display menu of layout setting.
 */
function vicuna_layout_menu() {
	$options = get_option('vicuna_layout');
	$layout_index = $options['index_layout']; ?>
<div class="wrap">
	<h2><?php _e('Layout', 'vicuna'); ?></h2>
	<p><?php _e('You can select layout of your each pages.', 'vicuna'); ?></p>
	<form method="post" action="<?php echo $_SERVER['PHP_SELF'] . '?page=' . basename(__FILE__); ?>">
		<p class="submit">
			<input type="submit" value="<?php _e('Save Changes &raquo;', 'vicuna'); ?>" />
		</p>
		<dl>
<?php vicuna_layout_selector(__('Index Layout', 'vicuna'), 'vicuna_index_layout', $options['index_layout']); ?>
<?php vicuna_layout_selector(__('Category Layout', 'vicuna'), 'vicuna_category_layout', $options['category_layout']); ?>
<?php vicuna_layout_selector(__('Archive Layout', 'vicuna'), 'vicuna_archive_layout', $options['archive_layout']); ?>
<?php vicuna_layout_selector(__('Tag Layout', 'vicuna'), 'vicuna_tag_layout', $options['tag_layout']); ?>
<?php vicuna_layout_selector(__('Single Layout', 'vicuna'), 'vicuna_single_layout', $options['single_layout']); ?>
<?php vicuna_layout_selector(__('Page Layout', 'vicuna'), 'vicuna_page_layout', $options['page_layout']); ?>
<?php vicuna_layout_selector(__('Search Layout', 'vicuna'), 'vicuna_search_layout', $options['search_layout']); ?>
<?php vicuna_layout_selector(__('404 Layout', 'vicuna'), 'vicuna_404_layout', $options['404_layout']); ?>
			<dt><?php _e('Multi Column Type', 'vicuna'); ?></dt>
			<dd><select name="vicuna_3column_type">
				<option value="0">Type 1</option>
				<option value="1"<?php if ($options['3column_type']) : echo ' selected'; endif; ?>>Type 2</option>
			</select></dd>
		</dl>
		<p class="submit">
			<input type="submit" value="<?php _e('Save Changes &raquo;', 'vicuna'); ?>" />
		</p>
	</form>
</div>
<?php
}

function vicuna_layout_selector($title, $name, $layout) {
?>
			<dt><?php echo $title; ?></dt>
			<dd><select name="<?php echo $name; ?>">
					<option value="single"<?php if (!$layout || $layout == "single") : echo ' selected'; endif; ?>>Single column</option>
					<option value="double"<?php if ($layout == "double") : echo ' selected'; endif; ?>>2column</option>
					<option value="multi"<?php if ($layout == "multi") : echo ' selected'; endif; ?>>3column</option>
			</select></dd>
<?php
}
?>